@@ -35,6 +35,9 @@ class Message:
 
     def _parse(self):
         # this weird looking bit is to make sure we do not do unnecessary checks when we have found a match
+        # it takes advantage of the fact that python's `or` works as true check/default value provider
+        # if the first check is false, it tries the next, then if thats false, it tries the next one, and it keeps doing this
+        # until one matches or it run out of functions to check
         (self._parse_usernotice()
          or self._parse_privmsg()
          or self._parse_whisper()
@@ -103,8 +106,12 @@ class Message:
             self.channel = channels[m['channel']]
             self.author = self.tags.all_tags.get('login')
             self.content = m['content']
-            if self.tags.msg_id in {'sub', 'resub', 'subgift', 'anonsubgift', 'submysterygift'}:
+            if self.tags.msg_id in {'sub', 'resub', 'subgift', 'anonsubgift', 'submysterygift', 'anongiftpaidupgrade',
+                                    'giftpaidupgrade'}:
                 self.type = MessageType.SUBSCRIPTION
+            elif self.tags.msg_id == 'raid':
+                self.type = MessageType.RAID
+                self.author = self.tags.all_tags.get('msg-param-login')
             else:
                 self.type = MessageType.USER_NOTICE
 
@@ -132,6 +139,10 @@ class Message:
     def is_subscription(self):
         return self.type is MessageType.SUBSCRIPTION
 
+    @property
+    def is_raid(self):
+        return self.type is MessageType.RAID
+
     @property
     def mention(self):
         return f'@{self.author}' if self.author else ''
@@ -176,6 +187,9 @@ class Message:
         elif self.type is MessageType.SUBSCRIPTION:
             return f'{self.author} subscribed to {self.channel_name}: {self.system_message}'
 
+        elif self.type is MessageType.RAID:
+            return f'{self.author} has raided {self.channel_name} with {self.tags.raid_viewer_count} viewers!'
+
         elif self.type is MessageType.USER_NOTICE:
             return f'USERNOTICE for {self.author}'
 
